@@ -1,4 +1,4 @@
-// Copyright 2016-2019 Francesco Biscani (bluescarni@gmail.com)
+// Copyright 2016-2020 Francesco Biscani (bluescarni@gmail.com)
 //
 // This file is part of the mp++ library.
 //
@@ -11,12 +11,13 @@
 
 // Start of defines instantiated by CMake.
 // clang-format off
-#define MPPP_VERSION_STRING "0.17"
+#define MPPP_VERSION_STRING "0.19"
 #define MPPP_VERSION_MAJOR 0
-#define MPPP_VERSION_MINOR 17
+#define MPPP_VERSION_MINOR 19
 #define MPPP_WITH_MPFR
 
 
+
 // clang-format on
 // End of defines instantiated by CMake.
 
@@ -79,10 +80,15 @@
 
 #define MPPP_HAVE_CONCEPTS
 
-#if defined(_MSC_VER)
-#define MPPP_CONCEPT_DECL concept
+// NOTE: GCC < 9 uses the syntax of the concept TS.
+#if defined(__GNUC__) && !defined(__clang__) && __GNUC__ < 9
+
+#define MPPP_CONCEPT_DECL concept bool
+
 #else
-#define MPPP_CONCEPT_DECL concept bool 
+
+#define MPPP_CONCEPT_DECL concept
+
 #endif
 
 #endif
@@ -137,4 +143,24 @@
 
 #endif
 
+// Wrapper for the C++17 [[fallthrough]] attribute.
+#if MPPP_CPLUSPLUS >= 201703L
+
+#define MPPP_FALLTHROUGH [[fallthrough]]
+
+#elif defined(__GNUC__) && !defined(__clang__) && __GNUC__ >= 7
+
+// On GCC>=7, if we are not using C++17 we can use
+// an alternative attribute:
+// https://developers.redhat.com/blog/2017/03/10/wimplicit-fallthrough-in-gcc-7/
+// This may be supported on some clang versions as well:
+// https://reviews.llvm.org/D63260
+#define MPPP_FALLTHROUGH [[gnu::fallthrough]]
+
+#else
+
+#define MPPP_FALLTHROUGH void(0)
+
+#endif
+
 #endif
