@@ -2,6 +2,8 @@
 
 if [[ "$(uname)" == "Darwin" ]]; then
     export ENABLE_QUADMATH=no
+    # Workaround for missing C++17 feature when building the tests.
+    export CXXFLAGS="$CXXFLAGS -DCATCH_CONFIG_NO_CPP17_UNCAUGHT_EXCEPTIONS"
 else
     export ENABLE_QUADMATH=yes
 fi
@@ -15,6 +17,7 @@ cmake \
     -DCMAKE_INSTALL_PREFIX=$PREFIX \
     -DCMAKE_PREFIX_PATH=$PREFIX \
     -DMPPP_WITH_MPFR=yes \
+    -DMPPP_WITH_ARB=yes \
     -DMPPP_WITH_QUADMATH=$ENABLE_QUADMATH \
     -DMPPP_BUILD_TESTS=yes \
     -DMPPP_INSTALL_LIBDIR=lib \
